django\_aws\_api\_gateway\_websockets.migrations package
========================================================

Submodules
----------

django\_aws\_api\_gateway\_websockets.migrations.0001\_initial module
---------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0001_initial
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.migrations.0002\_rename\_author\_websocketsession\_user module
----------------------------------------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0002_rename_author_websocketsession_user
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.migrations.0003\_auto\_20220706\_1018 module
----------------------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0003_auto_20220706_1018
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.migrations.0004\_auto\_20221208\_1227 module
----------------------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0004_auto_20221208_1227
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.migrations.0005\_apigatewayadditionalroute\_deployed module
-------------------------------------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0005_apigatewayadditionalroute_deployed
   :members:
   :show-inheritance:
   :undoc-members:

django\_aws\_api\_gateway\_websockets.migrations.0006\_auto\_20221215\_0847 module
----------------------------------------------------------------------------------

.. automodule:: django_aws_api_gateway_websockets.migrations.0006_auto_20221215_0847
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: django_aws_api_gateway_websockets.migrations
   :members:
   :show-inheritance:
   :undoc-members:
